@@ -106,7 +106,7 @@ pref("browser.chrome.image_icons.max_size", 1024);
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 110 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 110 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -114,7 +114,7 @@ pref("accessibility.warn_on_browsewithcaret", true);
 // unless accessibility.tabfocus is set by the user.
 pref("accessibility.tabfocus", 7);
 pref("accessibility.tabfocus_applies_to_xul", false);
-//@line 121 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 121 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -291,6 +291,8 @@ pref("capability.policy.default.XULControllers.removeController", "noAccess");
 pref("capability.policy.default.XULControllers.getControllerId", "noAccess");
 pref("capability.policy.default.XULControllers.getControllerById", "noAccess");
 pref("capability.policy.default.XULControllers.getControllerCount", "noAccess");
+pref("capability.policy.default.Selection.addSelectionListener", "UniversalXPConnect");
+pref("capability.policy.default.Selection.removeSelectionListener", "UniversalXPConnect");
 
 // Restrictions on the DOM for mail/news - see bugs 66938 and 84545
 pref("capability.policy.mailnews.sites", "mailbox: imap: news:");
@@ -473,7 +475,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 482 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 484 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -607,6 +609,7 @@ pref("network.IDN.whitelist.tw", true);
 pref("network.IDN.whitelist.vn", true);
 
 // non-ccTLDs
+pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
 pref("network.IDN.whitelist.museum", true);
 pref("network.IDN.whitelist.org", true);
@@ -668,7 +671,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 682 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 685 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -803,7 +806,7 @@ pref("mousewheel.withmetakey.sysnumlines",true);
 
 // on platforms where scroll messages differ between horizontal scroll
 // and back/forward button events we can activate them by default
-//@line 851 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 854 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 // disable horizontal scrolling to be able to use back/forward buttons
 pref("mousewheel.horizscroll.withnokey.action",2);
 pref("mousewheel.horizscroll.withnokey.numlines",-1);
@@ -820,7 +823,7 @@ pref("mousewheel.horizscroll.withaltkey.sysnumlines",false);
 pref("mousewheel.horizscroll.withmetakey.action",2);
 pref("mousewheel.horizscroll.withmetakey.numlines",-1);
 pref("mousewheel.horizscroll.withmetakey.sysnumlines",false);
-//@line 868 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 871 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 
 pref("profile.confirm_automigration",true);
 // profile.migration_behavior determines how the profiles root is set
@@ -953,15 +956,15 @@ pref("dom.max_script_run_time", 5);
 
 pref("svg.enabled", true);
 
-//@line 1331 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 1334 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1518 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 1521 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1707 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 1710 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1788 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 1791 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1791 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 1794 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1037,7 +1040,7 @@ pref("font.allow_double_byte_special_chars", true);
 
 // ar
 
-//@line 1927 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 1930 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 pref("font.name.serif.el", "misc-fixed-iso8859-7");
 pref("font.name.sans-serif.el", "misc-fixed-iso8859-7");
 pref("font.name.monospace.el", "misc-fixed-iso8859-7");
@@ -1095,7 +1098,7 @@ pref("font.name.sans-serif.zh-HK", "-arphic-Ming for ISO10646-big5hkscs-0");
 pref("font.name.monospace.zh-HK", "-arphic-Ming for ISO10646-big5hkscs-0");
 
 // zh-TW
-//@line 1986 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 1989 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.default.ar", "sans-serif");
 pref("font.size.variable.ar", 16);
@@ -1313,11 +1316,11 @@ pref("print.postscript.nativefont.zh-CN",          "");
 pref("print.postscript.nativefont.zh-TW",          "");
 pref("print.postscript.nativefont.zh-HK",          "");
 
-//@line 2206 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 2209 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2274 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 2277 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2300 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 2303 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2320 "/mozdisk/101build/mozilla/modules/libpref/src/init/all.js"
+//@line 2323 "/mozdisk/104build/mozilla/modules/libpref/src/init/all.js"
 
